
<script setup >
import  recharge from "@/api/financial/recharge";
import  archivesApi  from "@/api/archivesApi";
import  { sysDictData}  from "@/api/system/dict";
import setPostParams from "../../../utils/searchParams.js";
const { proxy } = getCurrentInstance();

/**
* 搜索相关
*/
/** 搜索按钮操作 */
function handleQuery() {
  getList({keywords:queryParams.value.name})
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

/**
 *  Table表格权限数据列表相关
 */
const pageParam = ref({
   total:0,
   limit:0,
   page:0,
})
const tableData = ref([]);
let  tableHeader = ref({
      userName: "用户姓名",
      userCode:"水表编号",
      userPhone: "用户电话",
      rechargeOrder: "充值订单号",
      rechargeType: "充值类型",
      paymentMethod: "支付方式",
      rechargeAmount: "充值金额",
      rechargeStatusView: "充值状态",
      createTimeView:"创建日期",

  })

/** 获取列表 */

const loading = ref(false);
async function getList(val) {
     loading.value = true;

    let postParam = setPostParams(val)
     await recharge().search(postParam).then((res) =>{
       tableData.value = res.data.list
       pageParam.value.total = res.data.total
       pageParam.value.limit = res.data.limit
       pageParam.value.page = res.data.page
   })
   loading.value = false;
}

/** 新增按钮操作 */
async function handleAdd() {
  reset();
  open.value = true;
  title.value = "充值";
}

/**
 *  新增/修改弹窗Form表单相关
 */
const open = ref(false);
const title = ref("");

const data = reactive({
form:{},
queryParams: {
   name: undefined,
},
rules: {
    userCode: [{required: true, message: '请选择用户', trigger: 'blur'}],
    rechargeAmount: [
      {required: true, message: '请输入充值金额', trigger: 'blur'},
      { pattern: "^(?!10000(?:\\.0{1,2})?$)(?:\\d{1,4}(?:\\.\\d{1,2})?|0(?:\\.\\d{1,2})?)$", message: '请输入0到9999.99之间的正整数或小数(最多保留两位小数)', trigger: 'blur' },
      ],
  },
});
const { queryParams, form, rules } = toRefs(data);

//获取支付方式
const paymentMethodList = ref()
const getMethod = async() =>{
  await sysDictData().searchType('pay_method').then((res) =>{
    paymentMethodList.value = res.data
  })
}
//获取账号列表
const userNameList = ref()
const getUser = async() =>{
  await archivesApi().search({limit:1500,page:1}).then((res) =>{
    userNameList.value = res.data.list
  })
}
 //选择用户,获取用户名及余额
 const changeUser = async(val) => {
    userNameList.value.forEach(item => {
      if(val == item.userCode){
          form.value.userName = item.userName
          form.value.walletBalance = item.walletBalance
      }
    })
    }

/** 提交按钮 */
function submitForm() {
  proxy.$refs["formRef"].validate(valid => {
    if (valid) {
        recharge().pay(form.value).then(res => {
          proxy.$modal.msgSuccess("充值成功");
          open.value = false;
          getList();
        }).catch(() =>{
           open.value = false;
           proxy.$modal.msgError("充值失败，请联系管理员");
        });
      }
  });
}

/** 取消按钮 */
function cancel() {
  open.value = false;
  reset();
}

/** 表单重置 */
function reset() {
  form.value = {
    walletBalance:'',
    userName: '',
    userCode: '',
    rechargeType: '柜台业务',
    paymentMethod: '1',
    rechargeAmount: '', //收取金额
  };
  proxy.resetForm("formRef");
}
getUser();
getMethod();
getList();
</script>
<template>
  <div class="app-container">
     <el-form :model="queryParams" ref="queryRef" :inline="true">
        <el-form-item prop="name">
           <el-input
              v-model="queryParams.name"
              placeholder="请输入水表编号或电话"
              clearable
              style="width: 200px"
              @keyup.enter="handleQuery"
           />
        </el-form-item>
        <el-form-item>
           <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
           <el-button icon="Refresh" @click="resetQuery">重置</el-button>
        </el-form-item>
     </el-form>

     <el-row :gutter="10" class="mb8">
        <el-col :span="1.5">
           <el-button
              type="primary"
              plain
              icon="Plus"
              @click="handleAdd"
           >充值</el-button>
        </el-col>
     </el-row>
     <!--表格及分页-->
     <el-table v-loading="loading" :data="tableData">
        <el-table-column
          v-for="(item, key, index) of tableHeader"
          :prop="key.toString()"
          :label="item"
          :key="index"
          align="center"
        ></el-table-column>
      </el-table>
      <pagination
        :total="pageParam.total"
        v-model:page="pageParam.page"
        v-model:limit="pageParam.limit"
        :page-sizes="[10,20,30]"
        @pagination="getList"
      />
     <!-- 添加或修改对话框 -->
     <el-dialog :title="title" v-model="open" append-to-body center>
        <el-form class="form-box" ref="formRef" :model="form" :rules="rules" label-width='auto'>
          <el-form-item label="户号"  prop="userCode">
              <el-select v-model="form.userCode" filterable clearable placeholder="请选择用户" @change="changeUser">
                  <el-option
                  v-for="item in userNameList"
                  :key="item.id"
                  :label="item.userCode"
                  :title="item.userCode"
                  :value="item.userCode">
                  </el-option>
              </el-select>
          </el-form-item>
          <el-form-item label="用户名称">{{ form.userName }}</el-form-item>
          <div class="hr"></div>
          <el-form-item label="余额" >
              <el-input v-model="form.walletBalance" disabled></el-input>
          </el-form-item>
          <el-form-item label="充值类型" >
              <el-input v-model="form.rechargeType" disabled></el-input>
          </el-form-item>
          <el-form-item label="支付方式"  prop="paymentMethod">
              <el-select v-model="form.paymentMethod" disabled  placeholder="请选择">
                  <el-option
                  v-for="item in paymentMethodList"
                  :key="item.dictValue"
                  :label="item.dictLabel"
                  :title="item.dictLabel"
                  :value="item.dictValue">
                  </el-option>
              </el-select>
          </el-form-item>
          <el-form-item label="充值金额"  prop="rechargeAmount">
              <el-input v-model="form.rechargeAmount"  ></el-input>
          </el-form-item>
      </el-form>
        <template #footer>
           <div class="dialog-footer">
              <el-button type="primary" @click="submitForm">确 定</el-button>
              <el-button @click="cancel">取 消</el-button>
           </div>
        </template>
     </el-dialog>
  </div>
</template>
<style lang="scss">
    .hr {
        width: 90%;
        border-bottom: 1px solid rgb(218, 218, 218);
        margin: 0 auto 30px;
    }
</style>
